/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use enumflags2::bitflags;

#[bitflags]
#[repr(u32)]
#[derive(
    Copy,
    Clone,
    Debug,
    PartialEq,
    Eq,
    zvariant::Type,
    strum::Display,
    strum::EnumIter,
    strum::AsRefStr,
)]
#[strum(serialize_all = "snake_case")]
pub enum DetailsFlags {
    Description,
    InstalledSize,
    Version,
    License,
    PackageState,
    Size,
    StagingVersion,
    Url,
}

#[cfg(test)]
mod test {
    use super::DetailsFlags;
    use zvariant::Type;

    #[test]
    fn signature() {
        assert_eq!(DetailsFlags::SIGNATURE, "u");
    }

    #[test]
    fn enum_as_str() {
        assert_eq!(DetailsFlags::InstalledSize.to_string(), "installed_size");
    }
}
