/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use tokio::task::JoinError;

#[derive(zbus::DBusError, Debug, PartialEq)]
#[zbus(prefix = "dev.Cogitri.apkPolkit2")]
pub enum Error {
    #[zbus(error)]
    ZBus(zbus::Error),
    AppStream(String),
    Fdo(String),
    Join(String),
    Anyhow(String),
}

pub type Result<T> = std::result::Result<T, Error>;

impl From<std::io::Error> for Error {
    fn from(e: std::io::Error) -> Self {
        log::error!("{e}");
        Error::AppStream(e.to_string())
    }
}

impl From<zbus::fdo::Error> for Error {
    fn from(e: zbus::fdo::Error) -> Self {
        log::error!("{e}");
        Error::Fdo(e.to_string())
    }
}

impl From<JoinError> for Error {
    fn from(e: JoinError) -> Self {
        log::error!("{e}");
        Error::Join(e.to_string())
    }
}

impl From<anyhow::Error> for Error {
    fn from(e: anyhow::Error) -> Self {
        log::error!("{e}");
        Error::Anyhow(e.to_string())
    }
}
