/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use crate::ApkPackage;
use apk_tools_sys::apk_change;

pub struct ApkChange {
    inner: apk_change,
}

impl ApkChange {
    pub fn from_raw(inner: apk_change) -> Self {
        Self { inner }
    }

    pub fn new_pkg(&self) -> Option<ApkPackage> {
        ApkPackage::from_ptr(self.inner.new_pkg)
    }

    pub fn old_pkg(&self) -> Option<ApkPackage> {
        ApkPackage::from_ptr(self.inner.old_pkg)
    }

    pub fn is_reinstall(&self) -> bool {
        self.inner.reinstall() != 0
    }
}

#[cfg(test)]
mod test {
    use crate::ApkChange;
    use crate::global_allocator::GlobalAllocator;
    use apk_tools_sys::apk_change;

    #[test]
    fn test_apk_change_is_reinstall() {
        let mut raw = apk_change::default();
        raw.set_reinstall(1);
        let change = ApkChange::from_raw(raw);
        assert!(change.is_reinstall());
    }

    #[test]
    fn test_apk_change_new_pkg() {
        let mut raw = apk_change::default();
        raw.new_pkg = GlobalAllocator::get_apk_package();
        raw.old_pkg = GlobalAllocator::get_apk_package();
        let change = ApkChange::from_raw(raw);
        assert!(std::ptr::eq(
            raw.new_pkg,
            change.new_pkg().unwrap().as_mut()
        ));
        assert!(std::ptr::eq(
            raw.old_pkg,
            change.old_pkg().unwrap().as_mut()
        ));
    }
}
