/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use anyhow::anyhow;
use apk_tools_sys::apk_error_str;
use std::ffi::{CStr, c_int};

pub trait ApkResult {
    fn into_result(self) -> anyhow::Result<()>;
}

impl ApkResult for c_int {
    fn into_result(self) -> anyhow::Result<()> {
        if self == 0 {
            return Ok(());
        }

        let apk_error = unsafe { CStr::from_ptr(apk_error_str(self)).to_str()? };

        Err(anyhow!(apk_error))
    }
}
