/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use crate::apk_provider::ApkProvider;
use crate::{generate_apk_array_drop_impl, generate_apk_array_impl};
use apk_tools_sys::{apk_provider, apk_provider_array};

#[derive(Debug)]
pub struct ApkProviderArray {
    inner: &'static mut apk_provider_array,
    is_owned: bool,
}

generate_apk_array_impl!(ApkProviderArray, apk_provider_array, apk_provider);
generate_apk_array_drop_impl!(ApkProviderArray);

impl ApkProviderArray {
    pub fn iter(&self) -> impl Iterator<Item = ApkProvider> + use<'_> {
        self.as_slice()
            .iter()
            .map(|&provider| ApkProvider::from_raw(provider))
    }

    pub fn push(&mut self, provider: apk_provider) {
        unsafe {
            self.push_raw(provider);
        }
    }
}
