/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

#![allow(clippy::new_without_default)]

pub mod apk_change;
pub mod apk_changeset;
pub mod apk_ctx;
pub mod apk_database;
pub mod apk_dependency;
pub mod apk_name;
pub mod apk_package;
pub mod apk_provider;
pub mod arrays;

mod apk_blob;
mod apk_repository;
mod apk_result;
#[cfg(test)]
mod global_allocator;
mod providers;

pub use apk_change::*;
pub use apk_changeset::*;
pub use apk_ctx::*;
pub use apk_database::*;
pub use apk_dependency::*;
pub use apk_name::*;
pub use apk_package::*;
pub use apk_provider::*;
pub use apk_repository::*;
pub use arrays::*;

pub(crate) use apk_blob::*;

#[macro_export]
macro_rules! generate_apk_base_impl {
    ($name:ident, $inner:ty) => {
        impl $name {
            #[allow(clippy::not_unsafe_ptr_arg_deref)]
            pub fn from_ptr(inner: *mut $inner) -> Option<Self> {
                if inner.is_null() {
                    return None;
                }

                Some(Self {
                    inner: unsafe { inner.as_mut() }.unwrap(),
                })
            }

            #[allow(dead_code)]
            pub(crate) fn as_mut(&mut self) -> &mut $inner {
                self.inner
            }
        }
    };
}
