/*
   Copyright: 2025 Rasmus Thomsen <oss@cogitri.dev>
   SPDX-License-Identifier: GPL-3.0-or-later
*/

use crate::*;
use std::convert::TryFrom;

// Can't be autogenerated by bindgen since these are defined in a header.
macro_rules! apk_array_funcs {
    ($x:ident, $type:ty) => {
        impl $x {
            pub fn as_slice(&self) -> Result<&[$type], std::num::TryFromIntError> {
                Ok(unsafe { self.item.as_slice(usize::try_from(self.hdr.num)?) })
            }

            pub fn as_mut_slice(&mut self) -> Result<&mut [$type], std::num::TryFromIntError> {
                Ok(unsafe { self.item.as_mut_slice(usize::try_from(self.hdr.num)?) })
            }

            pub fn iter(&self) -> Result<std::slice::Iter<$type>, std::num::TryFromIntError> {
                self.as_slice().map(|s| s.iter())
            }

            pub fn iter_mut(
                &mut self,
            ) -> Result<std::slice::IterMut<$type>, std::num::TryFromIntError> {
                self.as_mut_slice().map(|s| s.iter_mut())
            }
        }
    };
}

apk_array_funcs!(apk_string_array, *mut std::os::raw::c_char);
apk_array_funcs!(apk_hash_array, hlist_head);
apk_array_funcs!(apk_xattr_array, apk_xattr);
apk_array_funcs!(apk_provider_array, apk_provider);
apk_array_funcs!(apk_dependency_array, apk_dependency);
apk_array_funcs!(apk_package_array, *mut apk_package);
apk_array_funcs!(apk_name_array, *mut apk_name);
apk_array_funcs!(apk_protected_path_array, apk_protected_path);
apk_array_funcs!(apk_change_array, apk_change);
